import json
import os
import errno

# Class for handling service list updates
from common.appath import APPath


class ServiceList:
    def __init__(self):
        # Save the current list, we need to restore this after test is complete
        self.current_list = self.get_active_list()

    # Restore the service list to initial state
    def restore(self):
        self.update_list(self.current_list)

    # Update List to be triggered by updating it.
    def update_list(self, csv_list):
        print("Update Service Manager service list to:", csv_list)
        # Cleanup previous run errors, if any, for this service list update
        self.cleanup_previous_run(csv_list)

        with open(APPath.ServiceManagerDataRoot + 'new_servicelist.json', 'r') as data:
            svclist_json = json.load(data)
        current_list = svclist_json['List']
        svclist_json['List'] = csv_list

        # Write updated service list
        with open(APPath.ServiceManagerDataRoot + 'new_servicelist.json', 'w+') as data:
            # out_file.truncate(0)
            json.dump(svclist_json, data, indent=8)
        print(svclist_json)

        # Return the service list we overwrote
        return current_list

    # Return the current active list
    def get_active_list(self):
        with open(APPath.ServiceManagerDataRoot + 'active_servicelist.json', 'r') as data:
            svclist_json = json.load(data)

        current_list = svclist_json['List']
        print("active_list = ", current_list)
        return current_list

    # Return the current active list
    def get_active_error_message(self):
        with open(APPath.ServiceManagerDataRoot + 'active_servicelist.json', 'r') as data:
            svclist_json = json.load(data)

        error_message = svclist_json.get('ErrorMessage', None)
        print("error_message = ", error_message)
        return error_message

    # Verify if the active list is the one we expect
    def verify_active_list(self, csv_list):
        current_list = self.get_active_list()
        print("Verifying current active list: ", current_list, "==", csv_list)
        return csv_list == current_list

    # Make sure we clear errors from previous run. ServiceManager will not proceed if errors are present
    # for a service list.
    def cleanup_previous_run(self, csv_list):
        test_deb_err_file = APPath.ServiceManagerDataRoot + csv_list + ".processing.err"
        try:
            os.remove(test_deb_err_file)
        except OSError as e:
            if e.errno != errno.ENOENT:
                raise  # This is an unknown exception, raise it again to fail this test.
